@@ -16,8 +16,11 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
+## @deftypefn{Overloaded Operator} {} vertcat
 ## Vertical concatenation of @acronym{LTI} objects.  If necessary, object conversion
 ## is done by sys_group.  Used by Octave for "[sys1; sys2]".
+##
+## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: September 2009
