@@ -22,7 +22,7 @@
 ## Created: October 2009
 ## Version: 0.3
 
-function [zer, gain, info] = __zero__ (sys)
+function [zer, gain, info] = __zero__ (sys, ~)
 
   if (issiso (sys))
     num = get (sys.num{1});
@@ -31,7 +31,7 @@ function [zer, gain, info] = __zero__ (sys)
     gain = num(1) / den(1);
     info = [];
   else
-    warning ("tf: zero: converting to minimal state-space for zero computation of mimo tf");
+    warning ("tf: zero: converting to minimal state-space for zero computation of mimo tf\n");
     [zer, gain, info] = zero (ss (sys));
   endif
 
