@@ -163,6 +163,26 @@
 ## @end group
 ## @end example
 ##
+## The used method (see @strong{Algorithm} below) requires the following assumptions:
+## @table @asis
+## @item (A1)  (A,B2) is stabilizable and (C2,A) is detectable
+## @item (A2)  D12 is full column rank and D21 is full row rank,
+## @item (A3)  The matrix below has full column rank for all w
+## @example
+## @group
+##            | A-j*w*I  B2  |
+##            |   C1     D12 |
+## @end group
+## @end example
+## @item (A4)  The matrix below has full row rank for all w.
+## @example
+## @group
+##            | A-j*w*I  B1  |
+##            |   C2     D21 |
+## @end group
+## @end example
+## @end table
+##
 ## @strong{Algorithm}@*
 ## Uses @uref{https://github.com/SLICOT/SLICOT-Reference, SLICOT SB10FD, SB10DD and SB10AD},
 ## Copyright (c) 2020, SLICOT, available under the BSD 3-Clause
@@ -273,11 +293,21 @@ function [K, varargout] = hinfsyn (P, varargin)
   if (! isstabilizable (P(:, m1+1:m)))
     error ("hinfsyn: (A, B2) must be stabilizable");
   endif
-
   if (! isdetectable (P(p1+1:p, :)))
     error ("hinfsyn: (C2, A) must be detectable");
   endif
 
+  ## check assumption A2
+  D12 = d(1:p1,m1+1:m);
+  if (rank (D12) < columns (D12))
+    error ("hinfsyn: D12 must have full column rank");
+  endif
+
+  D21 = d(p1+1:p,1:m1);
+  if (rank (D21) < rows (D21))
+    error ("hinfsyn: D21 must have full row rank");
+  endif
+
   ## H-infinity synthesis
   switch (method)
     case "sub"              # sub-optimal controller
@@ -341,6 +371,7 @@ endfunction
 
 
 ## sub-optimal controller, continuous-time case
+%!test
 %!shared M, M_exp
 %! A = [-1.0  0.0  4.0  5.0 -3.0 -2.0
 %!      -2.0  4.0 -7.0 -2.0  0.0  3.0
@@ -394,10 +425,11 @@ endfunction
 %!
 %! M_exp = [KA, KB; KC, KD];
 %!
-%!assert (M, M_exp, 1e-4);
+%! assert (M, M_exp, 1e-4);
 
 
 ## sub-optimal controller, discrete-time case
+%!test
 %!shared M, M_exp
 %! A = [-0.7  0.0  0.3  0.0 -0.5 -0.1
 %!      -0.6  0.2 -0.4 -0.3  0.0  0.0
@@ -451,10 +483,11 @@ endfunction
 %!
 %! M_exp = [KA, KB; KC, KD];
 %!
-%!assert (M, M_exp, 1e-4);
+%! assert (M, M_exp, 1e-4);
 
 
 ## optimal controller, discrete-time case??? -- test for bisection method
+%!test
 %!shared M, M_exp, GAM_exp, GAM
 %! A = [-0.7  0.0  0.3  0.0 -0.5 -0.1
 %!      -0.6  0.2 -0.4 -0.3  0.0  0.0
@@ -509,5 +542,5 @@ endfunction
 %! M_exp = [KA, KB; KC, KD];
 %! GAM_exp = 111.294;
 %!
-%!assert (M, M_exp, 1e-1);
-%!assert (GAM, GAM_exp, 1e-3);
+%! assert (M, M_exp, 1e-1);
+%! assert (GAM, GAM_exp, 1e-3);
