@@ -87,10 +87,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_ident__", "__control_slicot_functions__.oct");
 DEFUN_DLD (__sl_ident__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot IB01AD Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_ib01ad__ (@dots{})\n"
+   "Wrapper for SLICOT function IB01AD.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -123,13 +124,12 @@ For internal use only.")
         const F77_INT ialg = args(5).int_value ();
         const F77_INT iconct = args(6).int_value ();
         const F77_INT ictrl = args(7).int_value ();
-        
+
         double rcond = args(8).double_value ();
         double tol_a = args(9).double_value ();
 
         double tol_b = rcond;
         double tol_c = rcond;
-        
             
         switch (imeth)
         {
@@ -194,7 +194,7 @@ For internal use only.")
         else if (meth_a == 'N' || (meth_a == 'M' && jobd == 'N'))
             ldr = 2*(m+l)*nobr;
         else
-            error ("__sl_ib01ad__: could not handle 'ldr' case");
+            error ("__sl_ident__: could not handle 'ldr' case");
         
         Matrix r (ldr, 2*(m+l)*nobr);
         ColumnVector sv (l*nobr);
@@ -215,6 +215,9 @@ For internal use only.")
             Matrix y = y_cell.elem(i).matrix_value ();
             Matrix u = u_cell.elem(i).matrix_value ();
 
+            if (y.any_element_is_inf_or_nan () || u.any_element_is_inf_or_nan ())
+              error ("__sl_ident__: inputs must not contain NaN or Inf\n");
+
             // y.rows == u.rows  is checked by iddata class
             // F77_INT m = TO_F77_INT (u.columns ());   // m: number of inputs
             // F77_INT l = TO_F77_INT (y.columns ());   // l: number of outputs
